@@ -1,6 +1,8 @@
+import os
 import abbrs
 
-RC_FILENAME = 'filenames-secure.json'
+PACKAGE_NAME = abbrs.current_path()
+RC_FILENAME = '{PACKAGE_NAME}.json'
 
 def make_dat(ls):
 	def is_mp4(x):
@@ -25,20 +27,30 @@ def make_dat(ls):
 	
 	return dat
 
+def restore():
+	dat = abbrs.load_json(RC_FILENAME)
+	for hash, filename in dat:
+		os.rename(hash, filename)
+	abbrs.suspend_file(RC_FILENAME)
+
+def secure():
+	dat = make_dat(os.listdir())
+	if len(dat) == 0:
+		print('MP4 files not found.')
+		return
+
+	abbrs.json_dump(RC_FILENAME, dat)
+	c = 1
+	for hash, filename in dat:
+		print(f'{c:2} {hash} = {filename}')
+		os.rename(filename, hash)
+		c += 1
+
 def main():
-	import os
 	if os.path.exists(RC_FILENAME):
-		dat = abbrs.load_json(RC_FILENAME)
-		
-		for hash, filename in dat:
-			os.rename(hash, filename)
+		restore()
 	else:
-		dat = make_dat(os.listdir())
-		abbrs.json_dump(RC_FILENAME, dat)
-		
-		for hash, filename in dat:
-			print(f'{hash} = {filename}')
-			os.rename(filename, hash)
+		secure()
 
 if __name__ == '__main__':
 	main()
\ No newline at end of file
